@@ -19,7 +19,7 @@
  * SECTION: vte-regex
  * @short_description: Regex for matching and searching. Uses PCRE2 internally.
  *
- * Since: 0.44
+ * Since: 0.46
  */
 
 #include "config.h"
@@ -27,39 +27,58 @@
 #include "vtemacros.h"
 #include "vteenums.h"
 #include "vteregex.h"
-
-#ifdef WITH_PCRE2
 #include "vtepcre2.h"
-#endif /* WITH_PCRE2 */
 
 #include "vteregexinternal.hh"
 
 struct _VteRegex {
         volatile int ref_count;
-#ifdef WITH_PCRE2
+        VteRegexPurpose purpose;
         pcre2_code_8 *code;
-#endif /* WITH_PCRE2 */
 };
 
-#ifdef WITH_PCRE2
 #define DEFAULT_COMPILE_OPTIONS (PCRE2_UTF)
 #define JIT_OPTIONS (PCRE2_JIT_COMPLETE)
 #define DEFAULT_MATCH_OPTIONS (0)
-#else
-#define DEFAULT_COMPILE_OPTIONS (0
-#define JIT_OPTIONS (0)
-#define DEFAULT_MATCH_OPTIONS (0)
-#endif /* WITH_PCRE2 */
 
-#ifdef WITH_PCRE2
+/* GRegex translation */
+
+typedef struct {
+        guint32 gflag;
+        guint32 pflag;
+} FlagTranslation;
+
+static void
+translate_flags(FlagTranslation const* const table,
+                gsize table_len,
+                guint32 *gflagsptr /* inout */,
+                guint32 *pflagsptr /* inout */)
+{
+        auto gflags = *gflagsptr;
+        auto pflags = *pflagsptr;
+        for (guint i = 0; i < table_len; i++) {
+                auto gflag = table[i].gflag;
+                if ((gflags & gflag) == gflag) {
+                        pflags |= table[i].pflag;
+                        gflags &= ~gflag;
+                }
+        }
+
+        *gflagsptr = gflags;
+        *pflagsptr = pflags;
+}
+
+/* internal */
 
 static VteRegex *
-regex_new(pcre2_code_8 *code)
+regex_new(pcre2_code_8 *code,
+          VteRegexPurpose purpose)
 {
         VteRegex *regex;
 
         regex = g_slice_new(VteRegex);
         regex->ref_count = 1;
+        regex->purpose = purpose;
         regex->code = code;
 
         return regex;
@@ -85,18 +104,6 @@ set_gerror_from_pcre_error(int errcode,
         return FALSE;
 }
 
-#else
-
-static gboolean
-set_unsupported_error(GError **error)
-{
-        g_set_error_literal(error, VTE_REGEX_ERROR, VTE_REGEX_ERROR_NOT_SUPPORTED,
-                            "PCRE2 not supported");
-        return FALSE;
-}
-
-#endif /* WITH_PCRE2 */
-
 G_DEFINE_BOXED_TYPE(VteRegex, vte_regex,
                     vte_regex_ref, (GBoxedFreeFunc)vte_regex_unref)
 
@@ -115,9 +122,8 @@ vte_regex_ref(VteRegex *regex)
 {
         g_return_val_if_fail (regex, NULL);
 
-#ifdef WITH_PCRE2
         g_atomic_int_inc (&regex->ref_count);
-#endif
+
         return regex;
 }
 
@@ -135,36 +141,19 @@ vte_regex_unref(VteRegex *regex)
 {
         g_return_val_if_fail (regex, NULL);
 
-#ifdef WITH_PCRE2
         if (g_atomic_int_dec_and_test (&regex->ref_count))
                 regex_free (regex);
-#endif
+
         return NULL;
 }
 
-/**
- * vte_regex_new:
- * @pattern: a regex pattern string
- * @pattern_length: the length of @pattern in bytes, or -1 if the
- *  string is NUL-terminated and the length is unknown
- * @flags: PCRE2 compile flags
- * @error: (allow-none): return location for a #GError, or %NULL
- *
- * Compiles @pattern into a regex. See man:pcre2pattern(3) for information
- * about the supported regex language.
- *
- * The regex will be compiled using %PCRE2_UTF and possibly other flags, in
- * addition to the flags supplied in @flags.
- *
- * Returns: (transfer full): a newly created #VteRegex, or %NULL with @error filled in
- */
-VteRegex *
-vte_regex_new(const char *pattern,
+static VteRegex *
+vte_regex_new(VteRegexPurpose purpose,
+              const char *pattern,
               gssize      pattern_length,
               guint32     flags,
               GError    **error)
 {
-#ifdef WITH_PCRE2
         pcre2_code_8 *code;
         int r, errcode;
         guint32 v;
@@ -199,11 +188,129 @@ vte_regex_new(const char *pattern,
                 return NULL;
         }
 
-        return regex_new(code);
-#else
-        set_unsupported_error(error);
-        return NULL;
-#endif /* WITH_PCRE2 */
+        return regex_new(code, purpose);
+}
+
+VteRegex *
+_vte_regex_new_gregex(VteRegexPurpose purpose,
+                      GRegex *gregex)
+{
+        g_return_val_if_fail(gregex != NULL, NULL);
+
+        guint32 pflags = 0;
+
+        static FlagTranslation const table[] = {
+                { G_REGEX_CASELESS,        PCRE2_CASELESS        },
+                { G_REGEX_MULTILINE,       PCRE2_MULTILINE       },
+                { G_REGEX_DOTALL,          PCRE2_DOTALL          },
+                { G_REGEX_EXTENDED,        PCRE2_EXTENDED        },
+                { G_REGEX_ANCHORED,        PCRE2_ANCHORED        },
+                { G_REGEX_DOLLAR_ENDONLY,  PCRE2_DOLLAR_ENDONLY  },
+                { G_REGEX_UNGREEDY,        PCRE2_UNGREEDY        },
+                { G_REGEX_NO_AUTO_CAPTURE, PCRE2_NO_AUTO_CAPTURE },
+                { G_REGEX_OPTIMIZE,        0                     }, /* accepted but unused */
+                { G_REGEX_FIRSTLINE,       PCRE2_FIRSTLINE       },
+                { G_REGEX_DUPNAMES,        PCRE2_DUPNAMES        }
+        };
+
+        guint32 gflags = g_regex_get_compile_flags(gregex);
+        translate_flags(table, G_N_ELEMENTS(table), &gflags, &pflags);
+
+        if (gflags != 0) {
+                g_warning("Incompatible GRegex compile flags left untranslated: %08x", gflags);
+        }
+
+        GError *err = nullptr;
+        auto regex = vte_regex_new(purpose, g_regex_get_pattern(gregex), -1, pflags, &err);
+        if (regex == NULL) {
+                g_warning("Failed to translated GRegex: %s", err->message);
+                g_error_free(err);
+        }
+        return regex;
+}
+
+guint32
+_vte_regex_translate_gregex_match_flags(GRegexMatchFlags flags)
+{
+        static FlagTranslation const table[] = {
+                { G_REGEX_MATCH_ANCHORED,         PCRE2_ANCHORED         },
+                { G_REGEX_MATCH_NOTBOL,           PCRE2_NOTBOL           },
+                { G_REGEX_MATCH_NOTEOL,           PCRE2_NOTEOL           },
+                { G_REGEX_MATCH_NOTEMPTY,         PCRE2_NOTEMPTY         },
+                { G_REGEX_MATCH_NOTEMPTY_ATSTART, PCRE2_NOTEMPTY_ATSTART }
+        };
+
+        guint32 gflags = flags;
+        guint32 pflags = 0;
+        translate_flags(table, G_N_ELEMENTS(table), &gflags, &pflags);
+        if (gflags != 0) {
+                g_warning("Incompatible GRegex match flags left untranslated: %08x", gflags);
+        }
+
+        return pflags;
+}
+
+/**
+ * vte_regex_new_for_match:
+ * @pattern: a regex pattern string
+ * @pattern_length: the length of @pattern in bytes, or -1 if the
+ *  string is NUL-terminated and the length is unknown
+ * @flags: PCRE2 compile flags
+ * @error: (allow-none): return location for a #GError, or %NULL
+ *
+ * Compiles @pattern into a regex for use as a match regex
+ * with vte_terminal_match_add_regex() or
+ * vte_terminal_event_check_regex_simple().
+ *
+ * See man:pcre2pattern(3) for information
+ * about the supported regex language.
+ *
+ * The regex will be compiled using %PCRE2_UTF and possibly other flags, in
+ * addition to the flags supplied in @flags.
+ *
+ * Returns: (transfer full): a newly created #VteRegex, or %NULL with @error filled in
+ */
+VteRegex *
+vte_regex_new_for_match(const char *pattern,
+                        gssize      pattern_length,
+                        guint32     flags,
+                        GError    **error)
+{
+        return vte_regex_new(VteRegexPurpose::match,
+                             pattern, pattern_length,
+                             flags,
+                             error);
+}
+
+/**
+ * vte_regex_new_for_search:
+ * @pattern: a regex pattern string
+ * @pattern_length: the length of @pattern in bytes, or -1 if the
+ *  string is NUL-terminated and the length is unknown
+ * @flags: PCRE2 compile flags
+ * @error: (allow-none): return location for a #GError, or %NULL
+ *
+ * Compiles @pattern into a regex for use as a search regex
+ * with vte_terminal_search_set_regex().
+ *
+ * See man:pcre2pattern(3) for information
+ * about the supported regex language.
+ *
+ * The regex will be compiled using %PCRE2_UTF and possibly other flags, in
+ * addition to the flags supplied in @flags.
+ *
+ * Returns: (transfer full): a newly created #VteRegex, or %NULL with @error filled in
+ */
+VteRegex *
+vte_regex_new_for_search(const char *pattern,
+                         gssize      pattern_length,
+                         guint32     flags,
+                         GError    **error)
+{
+        return vte_regex_new(VteRegexPurpose::search,
+                             pattern, pattern_length,
+                             flags,
+                             error);
 }
 
 #if 0
@@ -221,7 +328,6 @@ VteRegex *
 vte_regex_new_pcre(pcre2_code_8 *code,
                    GError      **error)
 {
-#ifdef WITH_PCRE2
         guint32 flags;
 
         g_return_val_if_fail(code != NULL, NULL);
@@ -232,14 +338,16 @@ vte_regex_new_pcre(pcre2_code_8 *code,
         g_return_val_if_fail(flags & PCRE2_NEVER_BACKSLASH_C, NULL);
 
         return regex_new(code);
-#else
-        set_unsupported_error(error);
-        return NULL;
-#endif
 }
 #endif
 
-#ifdef WITH_PCRE2
+gboolean
+_vte_regex_has_purpose(VteRegex *regex,
+                       VteRegexPurpose purpose)
+{
+        return regex->purpose == purpose;
+}
+
 /*
  * _vte_regex_get_pcre:
  * @regex: a #VteRegex
@@ -250,15 +358,10 @@ vte_regex_new_pcre(pcre2_code_8 *code,
 const pcre2_code_8 *
 _vte_regex_get_pcre(VteRegex *regex)
 {
-#ifdef WITH_PCRE2
         g_return_val_if_fail(regex != NULL, NULL);
 
         return regex->code;
-#else
-        return NULL;
-#endif
 }
-#endif
 
 /**
  * vte_regex_jit:
@@ -273,7 +376,6 @@ vte_regex_jit(VteRegex *regex,
               guint     flags,
               GError  **error)
 {
-#ifdef WITH_PCRE2
         int r;
 
         g_return_val_if_fail(regex != NULL, FALSE);
@@ -283,9 +385,6 @@ vte_regex_jit(VteRegex *regex,
                 return set_gerror_from_pcre_error(r, error);
 
         return TRUE;
-#else
-        return set_unsupported_error(error);
-#endif /* WITH_PCRE2 */
 }
 
 /*
@@ -299,7 +398,6 @@ vte_regex_jit(VteRegex *regex,
 gboolean
 _vte_regex_get_jited(VteRegex *regex)
 {
-#ifdef WITH_PCRE2
         PCRE2_SIZE s;
         int r;
 
@@ -308,7 +406,4 @@ _vte_regex_get_jited(VteRegex *regex)
         r = pcre2_pattern_info_8(regex->code, PCRE2_INFO_JITSIZE, &s);
 
         return r == 0 && s != 0;
-#else
-        return FALSE;
-#endif
 }
