@@ -53,15 +53,15 @@ vteseq_n_hash (register const char *str, register unsigned int len)
       127, 127, 127, 127, 127, 127, 127, 127, 127, 127,
       127, 127, 127, 127, 127, 127, 127, 127, 127, 127,
       127, 127, 127, 127, 127, 127, 127, 127, 127, 127,
-      127, 127, 127, 127, 127,   8,  21, 127, 127,  21,
-       10, 127, 127, 127, 127,  61, 127, 127, 127, 127,
+      127, 127, 127, 127, 127,   8,  21, 127, 127,  26,
+       21, 127, 127, 127, 127,  62, 127, 127, 127, 127,
       127, 127, 127, 127, 127, 127, 127, 127, 127, 127,
       127, 127, 127, 127, 127, 127, 127, 127, 127, 127,
       127, 127, 127, 127, 127, 127, 127, 127, 127, 127,
       127, 127, 127, 127, 127, 127, 127,   9,   8,  12,
-       22,   7,  10,  13,   7,  32,  15,  55,  29,  11,
-       31,   7,  18,  10,  31,  15,  37,  10,  43, 127,
-       34, 127,  16, 127, 127, 127, 127, 127, 127, 127,
+       22,   7,  10,  40,   7,  32,  15,  55,  29,  11,
+       31,   7,  18,  10,  31,  15,  37,  10,  38, 127,
+       34, 127,  11, 127, 127, 127, 127, 127, 127, 127,
       127, 127, 127, 127, 127, 127, 127, 127, 127, 127,
       127, 127, 127, 127, 127, 127, 127, 127, 127, 127,
       127, 127, 127, 127, 127, 127, 127, 127, 127, 127,
@@ -164,7 +164,7 @@ struct vteseq_n_pool_t
     char vteseq_n_pool_str71[sizeof("change-highlight-foreground-color-st")];
     char vteseq_n_pool_str72[sizeof("change-highlight-foreground-color-bel")];
     char vteseq_n_pool_str73[sizeof("set-scrolling-region")];
-    char vteseq_n_pool_str74[sizeof("reset-cursor-background_color")];
+    char vteseq_n_pool_str74[sizeof("iterm2-1337")];
     char vteseq_n_pool_str75[sizeof("set-cursor-style")];
     char vteseq_n_pool_str76[sizeof("erase-characters")];
     char vteseq_n_pool_str77[sizeof("set-icon-and-window-title")];
@@ -177,32 +177,33 @@ struct vteseq_n_pool_t
     char vteseq_n_pool_str84[sizeof("set-scrolling-region-from-start")];
     char vteseq_n_pool_str85[sizeof("delete-lines")];
     char vteseq_n_pool_str86[sizeof("screen-alignment-test")];
-    char vteseq_n_pool_str87[sizeof("designate-g1-line-drawing")];
+    char vteseq_n_pool_str87[sizeof("device-status-report")];
     char vteseq_n_pool_str88[sizeof("cursor-preceding-line")];
     char vteseq_n_pool_str89[sizeof("set-current-file-uri")];
     char vteseq_n_pool_str90[sizeof("character-position-absolute")];
     char vteseq_n_pool_str91[sizeof("request-terminal-parameters")];
-    char vteseq_n_pool_str92[sizeof("device-status-report")];
+    char vteseq_n_pool_str92[sizeof("send-primary-device-attributes")];
     char vteseq_n_pool_str93[sizeof("reset-highlight-foreground-color")];
     char vteseq_n_pool_str94[sizeof("line-position-absolute")];
     char vteseq_n_pool_str95[sizeof("reset-highlight-background-color")];
     char vteseq_n_pool_str96[sizeof("linux-console-cursor-attributes")];
-    char vteseq_n_pool_str97[sizeof("send-primary-device-attributes")];
-    char vteseq_n_pool_str98[sizeof("designate-g0-line-drawing")];
+    char vteseq_n_pool_str97[sizeof("send-secondary-device-attributes")];
+    char vteseq_n_pool_str98[sizeof("designate-g1-line-drawing")];
     char vteseq_n_pool_str99[sizeof("return-terminal-id")];
     char vteseq_n_pool_str100[sizeof("insert-blank-characters")];
-    char vteseq_n_pool_str101[sizeof("urxvt-777")];
-    char vteseq_n_pool_str102[sizeof("send-secondary-device-attributes")];
-    char vteseq_n_pool_str103[sizeof("designate-g1-plain")];
-    char vteseq_n_pool_str106[sizeof("designate-g1-british")];
+    char vteseq_n_pool_str101[sizeof("reset-cursor-background_color")];
+    char vteseq_n_pool_str102[sizeof("urxvt-777")];
+    char vteseq_n_pool_str103[sizeof("designate-g0-line-drawing")];
     char vteseq_n_pool_str108[sizeof("dec-device-status-report")];
     char vteseq_n_pool_str109[sizeof("insert-lines")];
-    char vteseq_n_pool_str114[sizeof("designate-g0-plain")];
+    char vteseq_n_pool_str114[sizeof("designate-g1-plain")];
     char vteseq_n_pool_str115[sizeof("erase-in-display")];
     char vteseq_n_pool_str116[sizeof("application-keypad")];
-    char vteseq_n_pool_str117[sizeof("designate-g0-british")];
+    char vteseq_n_pool_str117[sizeof("designate-g1-british")];
     char vteseq_n_pool_str118[sizeof("return-terminal-status")];
+    char vteseq_n_pool_str119[sizeof("designate-g0-plain")];
     char vteseq_n_pool_str121[sizeof("set-current-directory-uri")];
+    char vteseq_n_pool_str122[sizeof("designate-g0-british")];
     char vteseq_n_pool_str125[sizeof("change-cursor-background-color-st")];
     char vteseq_n_pool_str126[sizeof("change-cursor-background-color-bel")];
   };
@@ -261,7 +262,7 @@ static const struct vteseq_n_pool_t vteseq_n_pool_contents =
     "change-highlight-foreground-color-st",
     "change-highlight-foreground-color-bel",
     "set-scrolling-region",
-    "reset-cursor-background_color",
+    "iterm2-1337",
     "set-cursor-style",
     "erase-characters",
     "set-icon-and-window-title",
@@ -274,32 +275,33 @@ static const struct vteseq_n_pool_t vteseq_n_pool_contents =
     "set-scrolling-region-from-start",
     "delete-lines",
     "screen-alignment-test",
-    "designate-g1-line-drawing",
+    "device-status-report",
     "cursor-preceding-line",
     "set-current-file-uri",
     "character-position-absolute",
     "request-terminal-parameters",
-    "device-status-report",
+    "send-primary-device-attributes",
     "reset-highlight-foreground-color",
     "line-position-absolute",
     "reset-highlight-background-color",
     "linux-console-cursor-attributes",
-    "send-primary-device-attributes",
-    "designate-g0-line-drawing",
+    "send-secondary-device-attributes",
+    "designate-g1-line-drawing",
     "return-terminal-id",
     "insert-blank-characters",
+    "reset-cursor-background_color",
     "urxvt-777",
-    "send-secondary-device-attributes",
-    "designate-g1-plain",
-    "designate-g1-british",
+    "designate-g0-line-drawing",
     "dec-device-status-report",
     "insert-lines",
-    "designate-g0-plain",
+    "designate-g1-plain",
     "erase-in-display",
     "application-keypad",
-    "designate-g0-british",
+    "designate-g1-british",
     "return-terminal-status",
+    "designate-g0-plain",
     "set-current-directory-uri",
+    "designate-g0-british",
     "change-cursor-background-color-st",
     "change-cursor-background-color-bel"
   };
@@ -315,7 +317,7 @@ vteseq_n_lookup (register const char *str, register unsigned int len)
 {
   enum
     {
-      TOTAL_KEYWORDS = 94,
+      TOTAL_KEYWORDS = 95,
       MIN_WORD_LENGTH = 3,
       MAX_WORD_LENGTH = 37,
       MIN_HASH_VALUE = 10,
@@ -329,10 +331,10 @@ vteseq_n_lookup (register const char *str, register unsigned int len)
        0,  9,  9,  9, 10,  0,  0, 10,  5, 12, 13,  0,  9, 15,
       14, 11, 17, 11,  8,  9,  9, 15, 16, 11,  8, 15, 15, 16,
       26, 27, 26, 27, 12, 25, 14, 22, 25, 22, 14, 15, 23, 36,
-      37, 36, 37, 20, 29, 16, 16, 25, 16, 19, 27, 20, 13, 13,
-      31, 12, 21, 25, 21, 20, 27, 27, 20, 32, 22, 32, 31, 30,
-      25, 18, 23,  9, 32, 18,  0,  0, 20,  0, 24, 12,  0,  0,
-       0,  0, 18, 16, 18, 20, 22,  0,  0, 25,  0,  0,  0, 33,
+      37, 36, 37, 20, 11, 16, 16, 25, 16, 19, 27, 20, 13, 13,
+      31, 12, 21, 20, 21, 20, 27, 27, 30, 32, 22, 32, 31, 32,
+      25, 18, 23, 29,  9, 25,  0,  0,  0,  0, 24, 12,  0,  0,
+       0,  0, 18, 16, 18, 20, 22, 18,  0, 25, 20,  0,  0, 33,
       34
     };
   static const struct vteseq_n_struct wordlist[] =
@@ -450,8 +452,8 @@ vteseq_n_lookup (register const char *str, register unsigned int len)
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str72, VTE_SEQUENCE_HANDLER(vte_sequence_handler_change_highlight_foreground_color_bel)},
 #line 93 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str73, VTE_SEQUENCE_HANDLER(vte_sequence_handler_set_scrolling_region)},
-#line 90 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str74, VTE_SEQUENCE_HANDLER(vte_sequence_handler_reset_cursor_background_color)},
+#line 172 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str74, VTE_SEQUENCE_HANDLER(vte_sequence_handler_iterm2_1337)},
 #line 79 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str75, VTE_SEQUENCE_HANDLER(vte_sequence_handler_set_cursor_style)},
 #line 76 "vteseq-n.gperf"
@@ -476,8 +478,8 @@ vteseq_n_lookup (register const char *str, register unsigned int len)
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str85, VTE_SEQUENCE_HANDLER(vte_sequence_handler_delete_lines)},
 #line 100 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str86, VTE_SEQUENCE_HANDLER(vte_sequence_handler_screen_alignment_test)},
-#line 126 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str87, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g1_line_drawing)},
+#line 92 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str87, VTE_SEQUENCE_HANDLER(vte_sequence_handler_device_status_report)},
 #line 98 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str88, VTE_SEQUENCE_HANDLER(vte_sequence_handler_cursor_preceding_line)},
 #line 170 "vteseq-n.gperf"
@@ -486,8 +488,8 @@ vteseq_n_lookup (register const char *str, register unsigned int len)
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str90, VTE_SEQUENCE_HANDLER(vte_sequence_handler_character_position_absolute)},
 #line 145 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str91, VTE_SEQUENCE_HANDLER(vte_sequence_handler_request_terminal_parameters)},
-#line 92 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str92, VTE_SEQUENCE_HANDLER(vte_sequence_handler_device_status_report)},
+#line 160 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str92, VTE_SEQUENCE_HANDLER(vte_sequence_handler_send_primary_device_attributes)},
 #line 112 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str93, VTE_SEQUENCE_HANDLER(vte_sequence_handler_reset_highlight_foreground_color)},
 #line 105 "vteseq-n.gperf"
@@ -496,43 +498,44 @@ vteseq_n_lookup (register const char *str, register unsigned int len)
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str95, VTE_SEQUENCE_HANDLER(vte_sequence_handler_reset_highlight_background_color)},
 #line 161 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str96, VTE_SEQUENCE_HANDLER(vte_sequence_handler_linux_console_cursor_attributes)},
-#line 160 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str97, VTE_SEQUENCE_HANDLER(vte_sequence_handler_send_primary_device_attributes)},
-#line 123 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str98, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g0_line_drawing)},
+#line 162 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str97, VTE_SEQUENCE_HANDLER(vte_sequence_handler_send_secondary_device_attributes)},
+#line 126 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str98, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g1_line_drawing)},
 #line 84 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str99, VTE_SEQUENCE_HANDLER(vte_sequence_handler_return_terminal_id)},
 #line 114 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str100, VTE_SEQUENCE_HANDLER(vte_sequence_handler_insert_blank_characters)},
+#line 90 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str101, VTE_SEQUENCE_HANDLER(vte_sequence_handler_reset_cursor_background_color)},
 #line 171 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str101, VTE_SEQUENCE_HANDLER(vte_sequence_handler_urxvt_777)},
-#line 162 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str102, VTE_SEQUENCE_HANDLER(vte_sequence_handler_send_secondary_device_attributes)},
-#line 125 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str103, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g1_plain)},
-      {-1}, {-1},
-#line 127 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str106, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g1_british)},
-      {-1},
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str102, VTE_SEQUENCE_HANDLER(vte_sequence_handler_urxvt_777)},
+#line 123 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str103, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g0_line_drawing)},
+      {-1}, {-1}, {-1}, {-1},
 #line 136 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str108, VTE_SEQUENCE_HANDLER(vte_sequence_handler_dec_device_status_report)},
 #line 53 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str109, VTE_SEQUENCE_HANDLER(vte_sequence_handler_insert_lines)},
       {-1}, {-1}, {-1}, {-1},
-#line 122 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str114, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g0_plain)},
+#line 125 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str114, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g1_plain)},
 #line 77 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str115, VTE_SEQUENCE_HANDLER(vte_sequence_handler_erase_in_display)},
 #line 82 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str116, VTE_SEQUENCE_HANDLER(vte_sequence_handler_application_keypad)},
-#line 124 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str117, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g0_british)},
+#line 127 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str117, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g1_british)},
 #line 106 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str118, VTE_SEQUENCE_HANDLER(vte_sequence_handler_return_terminal_status)},
-      {-1}, {-1},
+#line 122 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str119, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g0_plain)},
+      {-1},
 #line 169 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str121, VTE_SEQUENCE_HANDLER(vte_sequence_handler_set_current_directory_uri)},
-      {-1}, {-1}, {-1},
+#line 124 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str122, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g0_british)},
+      {-1}, {-1},
 #line 89 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str125, VTE_SEQUENCE_HANDLER(vte_sequence_handler_change_cursor_background_color_st)},
 #line 88 "vteseq-n.gperf"
